/* easter1.c             Thomas R. Nicely          2010.04.23.0950
 *
 * Freeware copyright (c) 2010 Thomas R. Nicely <http://www.trnicely.net>.
 * Released into the public domain by the author, who disclaims any legal
 * liability arising from its use.
 *
 * SYNTAX: easter1 {parameter list}
 *
 * where the parameter list may specify years, months, days,
 * the Orthodox algorithm, or Julian calendar style (OS).
 *
 * EXAMPLES:
 *
 * easter1 y1=1943
 * easter1 y1=1940 y2=1950
 * easter1 m=April d=3 y1=1900 y2=2100
 * easter1 y1=1940 y2=1950 cal=OS
 * easter1 y1=1940 y2=1950 ch=Orthodox
 * easter1 m=April d=12 ch=Greek y1=1900 y2=2100
 * easter1 m=April d=12 ch=Eastern y1=1900 y2=2100 cal=OS
 *
 * The code can also parse certain untagged command lines, such as
 * "easter1 2010" or "easter1 2000 2020".
 *
 * Calculates Easter dates, including Gregorian, Julian, Western
 * Church (Roman Catholic and Protestant), and Eastern Orthodox.
 * Ultimately based on the algorithms of the Council of Nicaea
 * (ca. 325), Aloisius Lilius (Aloigi Giglio, 1576), Christopher
 * Clavius (1582), Karl Friedrich Gauss (ca. 1800), Christian Zeller
 * (1882), and Thomas H. O'Beirne (1965). See the following references:
 *
 * o "Elementary number theory," J. V. Uspensky and M. A. Heaslet,
 *      McGraw-Hill (1939), pp. 206-221.
 * o "Puzzles and paradoxes," Thomas H. O'Beirne, Oxford University
 *      Press (1965).
 * o "Easter is a quasicrystal," Ian Stewart, Scientific American
 *      184:3 (March 2001) 80-83.
 * o http://www.assa.org.au/edm.htmlhttp://www.smart  (Ronald W. Mallen)
 * o http://www.smart.net/~mmontes/ec-cal.html  (Marcos J. Montes)
 * o http://www.gmarts.org/index.php?go=412
 * o http://www.astro.uni.torun.pl/~kb/Papers/JRASC/Tropic.htm
 * o http://en.wikipedia.org/wiki/Tropical_year
 * o http://en.wikipedia.org/wiki/Julian_proleptic_calendar
 *
 * NOTES:
 *
 * (1) Dates are Gregorian (New Style), unless the qualifier "OS"
 *     or "Julian" appears.
 * (2) Easter dates are calculated by the algorithm of the Western
 *     (Roman Catholic or Protestant) churches, unless the qualifier
 *     "Orthodox", "Eastern", "Greek", or "Russian" appears.
 * (3) For years prior to 1583, all Easter dates are given in Old
 *     Style, whether the algorithm is Western or Orthodox; this code
 *     ignores the application of the so-called "proleptic" Gregorian
 *     calendar to dates prior to 15 October 1582.
 * (4) If Easter dates are desired for years B.C., treat them as
 *     negative and add 532 (the Great Cycle of the Julian calendar)
 *     or a multiple of 532 to the date (but note that, for example,
 *     adding 532 to the year 100 B.C. gives 433, not 432, due to the
 *     absence of the year zero in both the Gregorian and Julian
 *     calendars). The resulting Easter date is, at best, a purely
 *     theoretical date, not one actually observed; see (5) below.
 * (5) Easter dates for years prior to A.D. 326 are largely theoretical,
 *     since there appears to have been no generally accepted method
 *     for its computation prior to the Council of Nicaea in A.D. 325,
 *     and it was of course not observed prior to the Crucifixion,
 *     believed to have been sometime between A.D. 26 and A.D. 33.
 *     The Julian calendar itself extends only to B.C. 45, and the
 *     observance of leap years was irregular during its first half
 *     century. For years prior to B.C. 45, the common historical
 *     calendar is a proleptic Julian calendar, but there appears
 *     to be disagreement as to its theoretical leap years (is B.C. 1
 *     the final leap year B.C., or is it 4 B.C.?). The present code
 *     avoids the issue by requiring a positive (A.D.) date.
 * (5) The algorithm used for the Eastern Orthodox Church (and for the
 *     Western churches prior to 1583) ignores the calendar reforms
 *     proposed for the Eastern Orthodox calendar and algorithms during
 *     the 1920s. To the best of my knowledge, these reforms remain
 *     "tabled" and have never been officially approved or implemented.
 * (6) Mixed algorithms combined with years in the distant future may
 *     result in the Easter date retreating into the preceding year or
 *     advancing into the succeeding year (e.g., in 11327 A.D. Gregorian
 *     Easter Sunday would fall on 31 December of the previous year,
 *     Old Style; in 33808 A.D., Orthodox Easter Sunday would fall on
 *     January 1st of the following year, New Style). In such cases,
 *     the Easter date is converted to the other calendar format, and
 *     the result is specifically identified as OS (Old Style) or NS
 *     (New Style), to produce a sensible result.
 * (7) DISCLAIMER: This code has not been endorsed or approved by any
 *     religious institution, organization, or authority. Some
 *     denominations may follow different rules and observe different
 *     Easter dates. Finally, it must be anticipated that calendar
 *     reforms will eventually render the results obsolete for dates
 *     more than a few centuries into the future.
 */

#include "trn.h"
#include "conio3.h"

long iRCES(long iYear);
long iEOES(long iYear);
long iCorr(long iYear);
void vHelp(void);
long iHelpRequested(char *sz);

/* Note the declaration of szDate as a 2-dimensional array consisting
   of 367 strings each of 12 characters (maximum, including the
   terminating null). */

char szDate[367][12], szMonth[13][5], szName[128];
long iDPM[13];  /* Days in the preceding month */
FILE *fpOut;

static const char signature[]=
  "\n __easter1.c__Version 2010.04.23.0950__Freeware copyright (c) 2010"
  "\n Thomas R. Nicely <http://www.trnicely.net>. Released into the"
  "\n public domain by the author, who disclaims any legal liability"
  "\n arising from its use.\n";

/**********************************************************************/
int main(int argc, char **argv)
{
char sz[128], szArg[128], szStyle[7], szChurch[11], szMsg[128], szVerb[8],
  *pch;
long i, j, iEYD, iDateAdjusted, iTYD, iJulian, iEast, iJulianG,
  iEastG, iVal, iYear1, iYear2, iYear, iTemp, iFound, iOutfile=0,
  iFullDateGiven, iYearNow, iDayGiven, iMonthGiven, iMonthDay=1,
  iMonth=0, iContinue;
time_t timer1;
struct tm *ptm;

/*
  iTYD = Target year day (1 Jan = 1, 31 Dec = 366) for Easter.
  iTYD-60 = Target year day counted from 1 March=1.
  iEYD = Year day of Easter (e.g., 22 Mar = 82, 25 April = 116).
  Optional output file, specified by f=filename on command line,
    is primarily for debugging; it will contain one year and its
    Easter year day (1 Apr = 92, 29 Feb = 60, 1 Jan = 1) per line.
*/

atexit(vAtExit);
signal(SIGTERM, exit);
signal(SIGINT, exit);
signal(SIGBREAK, exit);
signal(SIGQUIT, exit);
signal(SIGKILL, exit);
setbuf(stdout, NULL);
setbuf(stderr, NULL);

strcpy(szName, argv[0]);
if((argc < 2) || iHelpRequested(argv[1]))
  {
  vHelp();
  exit(EXIT_FAILURE);
  }

/* Define the array of calendar dates */

szDate[0][0]=0;
for(i=1; i <= 31; i++)sprintf(szDate[i    ], "January %ld", i);
for(i=1; i <= 29; i++)sprintf(szDate[i+ 31], "February %ld", i);
for(i=1; i <= 31; i++)sprintf(szDate[i+ 60], "March %ld", i);
for(i=1; i <= 30; i++)sprintf(szDate[i+ 91], "April %ld", i);
for(i=1; i <= 31; i++)sprintf(szDate[i+121], "May %ld", i);
for(i=1; i <= 30; i++)sprintf(szDate[i+152], "June %ld", i);
for(i=1; i <= 31; i++)sprintf(szDate[i+182], "July %ld", i);
for(i=1; i <= 31; i++)sprintf(szDate[i+213], "August %ld", i);
for(i=1; i <= 30; i++)sprintf(szDate[i+244], "September %ld", i);
for(i=1; i <= 31; i++)sprintf(szDate[i+274], "October %ld", i);
for(i=1; i <= 30; i++)sprintf(szDate[i+305], "November %ld", i);
for(i=1; i <= 31; i++)sprintf(szDate[i+335], "December %ld", i);

/* Define the array of month abbreviations */

szMonth[0][0]=0;
strcpy(szMonth[1], "jan");
strcpy(szMonth[2], "feb");
strcpy(szMonth[3], "mar");
strcpy(szMonth[4], "apr");
strcpy(szMonth[5], "may");
strcpy(szMonth[6], "jun");
strcpy(szMonth[7], "july");  /* Avoid jul, could also mean Julian */
strcpy(szMonth[8], "aug");
strcpy(szMonth[9], "sep");
strcpy(szMonth[10], "oct");
strcpy(szMonth[11], "nov");
strcpy(szMonth[12], "dec");

/* Define the iDPM array, containing the number of days in the months
   preceding month number n. */

iDPM[0]=iDPM[1]=0;
iDPM[2]=31;
iDPM[3]=60;  /* Includes 29 Feb */
iDPM[4]=91;
iDPM[5]=121;
iDPM[6]=152;
iDPM[7]=182;
iDPM[8]=213;
iDPM[9]=244;
iDPM[10]=274;
iDPM[11]=305;
iDPM[12]=335;

iTYD=0;
iJulianG=0;
iEastG=0;
iFullDateGiven=0;
iMonthGiven=0;
iMonth=0;
iDayGiven=0;
iMonthDay=0;
iYear1=iYear2=0;
time(&timer1);
ptm = localtime(&timer1);
iYearNow = ptm->tm_year + 1900;  /* Current year, for grammar */

for(i=1; i < argc; i++)
  {
  strcpy(szArg, strlwr(argv[i]));
  szTrimMWS(szArg);

  /* First decipher command-line tokens assuming direct format */

  iVal=atol(szArg);
  if(iVal > 31)  /* Year AD */
    {
    if(iYear1==0)
      iYear1=iVal;
    else if(iYear2==0)
      iYear2=iVal;
    continue;
    }
  else if(iVal > 0)  /* Day of month */
    {
    iDayGiven=1;
    iMonthDay = iVal;
    continue;
    }
  else if(iVal < 0)
    {
    fprintf(stderr, "\n ...Years A.D. (positive) must be specified.");
    exit(EXIT_FAILURE);
    }
  else if(!strcmp(szArg, "0"))
    {
    fprintf(stderr, "\n ...Years A.D. (positive) must be specified.");
    exit(EXIT_FAILURE);
    }
  /* Calendar */
  if(strstr(szArg, "juli") || strstr(szArg, "old") || strstr(szArg, "os")
      || strstr(szArg, "o.s."))
    {
    iJulianG=1;
    continue;
    }
  if(strstr(szArg, "greg") || strstr(szArg, "new") || strstr(szArg, "ns")
      || strstr(szArg, "n.s."))
    {
    iJulianG=0;
    continue;
    }
  /* Church */
  if(strstr(szArg, "east") || strstr(szArg, "orth")
      || strstr(szArg, "greek") || strstr(szArg, "russ"))
    {
    iEastG=1;
    continue;
    }
  if(strstr(szArg, "west") || strstr(szArg, "rom") || strstr(szArg, "cath")
      || strstr(szArg, "prot"))
    {
    iEastG=0;
    continue;
    }
  iContinue=0;
  for(j=2; j < 13; j++)  /* Check for the month */
    if(strstr(szArg, szMonth[j]))
      {
      iMonth=j;
      iMonthGiven=1;
      iContinue=1;
      }
  if(iContinue)continue;

  /* Now parse tokens assuming the "key=val" format */

  if(!strchr(szArg, '='))
    {
    fprintf(stderr, "\n *** Unexpected argument format ==>%s<==\n", szArg);
    vHelp();
    exit(EXIT_FAILURE);
    }
  pch=strstr(szArg, "f=");
  if((pch) && (!iOutfile))
    {
    fpOut=fopen(pch+2, "at");
    if(!fpOut)
      {
      fprintf(stderr, "\n ...Unable to open output file %s.", pch+2);
      exit(EXIT_FAILURE);
      }
    iOutfile=1;
    continue;
    }
  pch=strstr(szArg, "y1=");
  if(pch)
    {
    iYear1=atol(pch+3);
    continue;
    }
  pch=strstr(szArg, "y2=");
  if(pch)
    {
    iYear2=atol(pch+3);
    continue;
    }
  pch=strstr(szArg, "cal=");
  if(pch)
    {
    if(strstr(szArg, "os"))iJulianG=1;
    if(strstr(szArg, "ns"))iJulianG=0;
    if(strstr(szArg, "old"))iJulianG=1;
    if(strstr(szArg, "new"))iJulianG=0;
    if(strstr(szArg, "j"))iJulianG=1;  /* Julian */
    if(strstr(szArg, "g"))iJulianG=0;  /* Gregorian */
    continue;
    }
  pch=strstr(szArg, "ch=");
  if(pch)
    {
    if(strstr(szArg, "east"))iEastG=1;
    if(strstr(szArg, "orth"))iEastG=1;
    if(strstr(szArg, "greek"))iEastG=1;
    if(strstr(szArg, "russ"))iEastG=1;
    if(strstr(szArg, "west"))iEastG=0;
    if(strstr(szArg, "rom"))iEastG=0;
    if(strstr(szArg, "cath"))iEastG=0;
    if(strstr(szArg, "prot"))iEastG=0;
    continue;
    }
  pch=strstr(szArg, "m=");
  if(pch)
    {
    iVal=atol(pch+2);
    iContinue=0;
    for(j=2; j < 13; j++)  /* Check for the month */
      {
      if((j==iVal) || strstr(szArg, szMonth[j]))
	{
	iMonth=j;
	iMonthGiven=1;
	iContinue=1;
	}
      }
    if(iContinue)continue;
    }
  pch=strstr(szArg, "d=");  /* day of month */
  if(pch)
    {
    iDayGiven=1;
    iMonthDay = atol(pch+2);
    continue;
    }
  }

if(iMonthGiven != iDayGiven)
  {
  fprintf(stderr, "\n ERROR: Month and day of month required together.");
 exit(EXIT_FAILURE);
  }
if(iMonthGiven && iDayGiven)
  {
  iFullDateGiven=1;
  iTYD = iDPM[iMonth] + iMonthDay;
  }

/* Normalize and check the specified years */

if(iYear1*iYear2==0)
  {
  iTemp=__MAX2(iYear1, iYear2);
  if(iTemp <= 0)
    {
    fprintf(stderr, "\n ...Years A.D. (positive) must be specified.");
    exit(EXIT_FAILURE);
    }
  iYear1=iYear2=iTemp;
  }

if((iYear1 < 1) || (iYear2 < 1))
  {
  fprintf(stderr, "\n ...Years A.D. (positive) must be specified.");
  exit(EXIT_FAILURE);
  }

if((iYear1 > iYear2))
  {
  iTemp=iYear1;
  iYear1=iYear2;
  iYear2=iTemp;
  }

if((iYear1 < 1583) && (iYear2 < 1583))
  {
  iJulianG=1;
  iEastG=1;
  }

if(iEastG)
  strcpy(szChurch, " Orthodox ");
else
  strcpy(szChurch, " ");

if(iFullDateGiven)
  {
  if(iYear1==0)iYear1=1753;
  if(iYear2==0)iYear2=iYear1 + 400;
  if(iJulianG)
    strcpy(szStyle, " OS ");
  else
    strcpy(szStyle, " ");
  sprintf(szMsg,
    "%sEaster falls on %s%sin these years between %ld and %ld:",
    szChurch, szDate[iTYD], szStyle, iYear1, iYear2);
  printf("\n%s\n\n", szMsg);
  if(iOutfile)fprintf(fpOut, "\n%s\n", szMsg);
  iFound=0;
  for(iYear=iYear1; iYear <= iYear2; iYear++)
    {
    if(iYear==0)continue;
    if(iYear < 1583)
      iJulian=iEast=1;
    else
      {
      iJulian=iJulianG;
      iEast=iEastG;
      }
    if(iEast)
      {
      iEYD=iEOES(iYear) + (iJulian==0)*iCorr(iYear) + 60;
      if((iEYD==60) && (iYear % 4 != 0))iEYD=59;  /* Feb 29 OS */
      if(iEYD==iTYD)
	{
	iFound=1;
	if(wherex() > 73)printf("\n");
	printf(" %5ld", iYear);
	if(iOutfile)fprintf(fpOut, " %5ld %3ld\n", iYear, iTYD);
	}
      }
    else
      {
      iEYD=iRCES(iYear) - (iJulian==1)*iCorr(iYear) + 60;
      if((iEYD==60) && (iYear % 4 != 0))iEYD=59;  /* Feb 29 OS */
      if(iEYD==iTYD)
	{
	iFound=1;
	if(wherex() > 73)printf("\n");
	printf(" %5ld", iYear);
	if(iOutfile)fprintf(fpOut, " %5ld %3ld\n", iYear, iTYD);
	}
      }
    }
  if(!iFound)printf(" *** NONE ***");
  }

BY_YEARS:

if(!iFullDateGiven)
  {
  if(iYear1==iYear2)
    {
    if(iYear1 < 1583)
      iJulian=iEast=1;
    else
      {
      iJulian=iJulianG;
      iEast=iEastG;
      }
    if(iJulian)
      strcpy(szStyle, " OS");
    else
      szStyle[0]=0;
    if(iEast)
      iEYD=iEOES(iYear1) + (iJulian==0)*iCorr(iYear1) + 60;
    else
      iEYD=iRCES(iYear1) - (iJulian==1)*iCorr(iYear1) + 60;
    if((iEYD==60) && (iYear1 % 4 != 0))iEYD=59;  /* Feb 29 OS */
    if(iOutfile)fprintf(fpOut, " %5ld %3ld\n", iYear1, iEYD);
    /* If the calculated date falls before 1 Jan or after 31 Dec,
       convert to the other calendar */
    if(iEYD < 1)
      {
      iJulian = 0;
      strcpy(szStyle, " NS** ");
      iEYD=iEYD + iCorr(iYear1);
      }
    else if(iEYD > 366)
      {
      iJulian = 1;
      strcpy(szStyle, " OS** ");
      iEYD=iEYD - iCorr(iYear1);
      }
    if(iYear1 < iYearNow)
      strcpy(szVerb, "was");
    else if(iYear1==iYearNow)
      strcpy(szVerb, "is");
    else
      strcpy(szVerb, "will be");
    if(iYear1 < 1583)strcpy(szChurch, " ");
    sprintf(szMsg,
      "In %ld,%sEaster Sunday %s %s%s.", iYear1, szChurch, szVerb,
	szDate[iEYD], szStyle);
    printf("\n %s", szMsg);
    }
  else
    {
    if(iYear2 < 1583)strcpy(szChurch, " ");
    sprintf(szMsg,
      "The%sEaster dates for the years %ld to %ld are as follows:",
      szChurch, iYear1, iYear2);
    printf("\n %s\n", szTrimMWS(szMsg));
    for(iYear=iYear1; iYear <= iYear2; iYear++)
      {
      if(iYear < 1583)
	iJulian=iEast=1;
      else
	{
	iJulian=iJulianG;
	iEast=iEastG;
	}
      if(iJulian)
	strcpy(szStyle, " OS");
      else
	szStyle[0]=0;
      if(iEast)
	iEYD=iEOES(iYear) + (iJulian==0)*iCorr(iYear) + 60;
      else
	iEYD=iRCES(iYear) - (iJulian==1)*iCorr(iYear) + 60;
      if((iEYD==60) && (iYear % 4 != 0))iEYD=59;  /* Feb 29 OS */
      if(iOutfile)fprintf(fpOut, " %5ld %3ld\n", iYear, iEYD);
      /* If the calculated date falls before 1 Jan or after 31 Dec,
	 convert to the other calendar */
      if(iEYD < 1)
	{
	iJulian = 0;
	strcpy(szStyle, " NS** ");
	iEYD=iEYD + iCorr(iYear1);
	}
      else if(iEYD > 366)
	{
	iJulian = 1;
	strcpy(szStyle, " OS** ");
	iEYD=iEYD - iCorr(iYear1);
	}
      printf("\n  %5ld   %s %s", iYear, szDate[iEYD], szStyle);
      }
    }
  }

return(EXIT_SUCCESS);
}
/*********************************************************************/
long iRCES(long iYear)
{
/* This is the 19th-century algorithm of Gauss and Zeller as described
   in "Elementary number theory," J. V. Uspensky and M. A. Heaslet,
   McGraw-Hill (1939), pp. 206-221. The return value is the March date
   iEMD (April, if iEMD > 31) of Easter Sunday in iYear, Gregorian/New
   Style, as observed by the Roman Catholic Church. Note that in
   Uspensky and Heaslet, the formula for the old church calendar
   epact (p. 214) should be corrected to (11c - 3) mod 30. */

long iCent, iRem4, iRem7, iRem19, iLeap, iPFM, iSun, iEMD, iM,
  iException[]={0,0,1,0,0,1,0,0,0,0,1,0,0,1,0,0,1,0,0,0,0,1,0,0,1,0,0,0,0,1};

if(iYear < 1)return(INT32_MIN);  /* Error */
iYear = iYear % 5700000L;
  /* Thomas R. Nicely demonstrated in 1977 that the Gregorian algorithm
     is periodic with period 5,700,000 years in the Gregorian Calendar */
iCent = iYear/100;
iRem4 = iYear % 4;  /* leap cycle */
iRem7 = iYear % 7;  /* weekly cycle */
iRem19 = iYear % 19;  /* golden cycle; golden number (GN) - 1 */
iLeap = 4 + iCent - iCent/4;  /* Gregorian count of centenary leap days */
iM = (11 + iLeap - ((8*iCent + 13)/25)) % 30; /* Gauss-Zeller fudge factor */
iPFM = (19*iRem19 + iM) % 30;  /* offset of PFM from March 21 */
iSun = (2*iRem4 + 4*iRem7 + 6*iPFM + iLeap) % 7 + 1;
  /* ...offset from PFM to following Sunday */
iEMD = 21 + iPFM + iSun;  /* normal case */
if(iSun==7)  /* some exceptions when PFM falls on Sunday */
  {
  if(iPFM==29)iEMD=50;  /* All 04.26 ==> 04.19 */
  if((iPFM==28) && iException[iM])iEMD=49;  /* Certain 04.25 ==> 04.18 */
  }
return(iEMD);
}
/*********************************************************************/
long iEOES(long iYear)
{
/* Returns the March date iEMD of Easter Sunday (iEMD=22 for 22 March;
   if iEMD > 31, Easter falls on April (iEMD - 31)th). The date is Old
   Style, as computed by the Old Church (Eastern Orthodox) algorithm.
   Note that in Uspensky and Heaslet, the formula for the old church
   calendar epact (p. 214) should be corrected to (11c - 3) mod 30. */

long iCent, iRem4, iRem7, iRem19, iPFM, iSun, iEMD, iYear1;

if(iYear < 1)return(INT32_MIN);  /* Error */
iYear = iYear % 532;   /* Great Cycle of the Julian calendar */
iRem19 = iYear%19;  /* Golden Number (GN) - 1 */
iRem7 = iYear%7;  /* weekly cycle */
iRem4 = iYear%4;  /* leap cycle */
iPFM = (19*iRem19 + 15) % 30;  /* offset of PFM from 21 March OS */
  /* Offset of Paschal Full Moon from 21 March OS;
     Epact is (8 + 11*iRem19) % 30 = (11*GN - 3) % 30 */
iSun = (2*iRem4 + 4*iRem7 + 6*iPFM + 6) % 7 + 1;
  /* ...additional offset to the next Sunday after the PFM */
iEMD = 21 + iPFM + iSun;  /* March Easter date in the Julian calendar */
return(iEMD);
}
/*********************************************************************/
long iCorr(long iYear)
{
/* Returns the number of days that must be added to the Julian date to
   obtain the Gregorian date, in year iYear (assumed positive). Note
   that the number returned is one too many for Gregorian dates between
   1 Jan and 28 Feb in the years 1700, 1800, 1900, 2100, etc. */

long iCent;

if(iYear < 1)return(INT32_MIN);  /* Error */
iCent=iYear/100;
return(iCent - 2 - iCent/4);
}
/*********************************************************************/
void vHelp(void)
{
printf("%s", signature);
printf("\n SYNTAX: %s {parameters}", szName);
printf("\n");
printf("\n Calculates the date of Easter Sunday.");
printf(" Press a key to view some examples: ");
getch();
__clearline();
printf("\r EXAMPLES:");
printf("\n");
printf("\n %s y1=1943", szName);
printf("\n %s y1=1940 y2=1950", szName);
printf("\n %s y1=1940 y2=1950 cal=Julian", szName);
printf("\n %s m=April d=12 ch=Orthodox y1=1900 y2=2100", szName);
printf("\n");
printf("\n Note that default results are for the Gregorian (New Style)");
printf("\n calendar and the Western Church (Roman Catholic and");
printf("\n Protestant). For years prior to 1583, results will");
printf("\n always be computed with the Orthodox (old church) algorithm");
printf("\n and the OS (Old Style) date. Results for years prior to");
printf("\n A.D. 326 are theoretical, and years B.C. are excluded.");
printf("\n");
printf("\n See the source code comments for additional documentation");
printf("\n and references.");
printf("\n");
printf("\n DISCLAIMER: This code has not been endorsed or approved by");
printf("\n any religious institution, organization, or authority. Certain");
printf("\n denominations may follow different rules and observe different");
printf("\n Easter dates. It is likely that calendar reforms will");
printf("\n eventually render the results obsolete for dates more than a");
printf("\n few centuries into the future.");
return;
}
/*********************************************************************/
long iHelpRequested(char *sz)
{
if(strchr(sz, '?'))return(1);
if(strstr(sz, "help"))return(1);
if(!stricmp(sz, "/h"))return(1);
if(!stricmp(sz, "-h"))return(1);
if(!stricmp(sz, "--h"))return(1);
return(0);
}
/*********************************************************************/
